#
# spec file for package python-case
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-case
Version:        1.5.3
Release:        9.1
Summary:        Python unittest Utilities
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/celery/case
Source:         https://files.pythonhosted.org/packages/source/c/case/case-%{version}.tar.gz
Patch0:         remove_unittest2.patch
Patch1:         remove_coverage.patch
Patch2:         remove-nose.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pytest
Requires:       python-setuptools
Requires:       python-six
BuildArch:      noarch
%python_subpackages

%description
Python unittest Utilities.

%prep
%setup -q -n case-%{version}
%autopatch -p1

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

#%%check no tests exist https://github.com/celery/case/issues/8

%files %{python_files}
%license LICENSE
%doc Changelog README.rst
%{python_sitelib}/case
%{python_sitelib}/case-%{version}*-info

%changelog
* Thu May 15 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Sun Jun 11 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu Oct 13 2022 Dirk Müller <dmueller@suse.com>
- use https for urls
* Wed Jul 20 2022 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded Requires on python-mock.
* Wed Sep 15 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add remove-nose.patch:
  * Stop using nose to skip tests.
- Adjust Requires from python-nose to python-pytest.
* Sun Aug 16 2020 John Vandenberg <jayvdb@gmail.com>
- Remove test dependencies and %%check as there are no tests
* Thu Oct  3 2019 John Vandenberg <jayvdb@gmail.com>
- Remove dependency on coverage
  Add remove_coverage.patch to facilitate that
* Mon Aug 13 2018 mcepl@suse.com
- Remove dependency on unittest2
  Add remove_unittest2.patch to facilitate that
* Wed Mar 15 2017 tbechtold@suse.com
- update to 1.5.3:
  - ``patch.multiple`` now works.
  - Using setup/teardown instead of setup_method/teardown_method was a bad idea.
  - 1.5.0 had a left over print statement :blush:
  - Pytest: When decorating classes using the ``skip.*`` and ``mock.*``
    decorators, these now augment ``cls.setup``/``cls.teardown`` instead of
    ``cls.setup_method``/``cls.teardown_method``.
  - Pytest: Adds ``patching.object``.
  - Adds new helper: ``case.pytest.fixture_with_options``.
  - All case decorators now works with py.test classes.
  - Py.test: Adds new `stdouts` fixture that patches :data:`sys.stdout`,
    and :data:`sys.stderr`.
  - Py.test: The `patching` fixture can now mock modules.
  - Case is now a py.test plug-in and provides a `patching` fixture
    as a shortcut to `monkeypatch` setting the value to a mock.
  - Case decorators now supports py.test.
  - Patcher created by create_patcher now accepts *args.
  - ``mock.reload_modules``: Fixed compatibility with Python 3.
  - ``mock.reload_modules`` now re-imports the module and
    calls ``reload()`` on it.
  - Adds ``mock.mute`` decorator to suppress stdout with no return value.
  - Adds ``Mock.on_nth_call_do_raise(excA, excB, n)``.
- Fix license
- Convert to singlespec approach
* Fri Jun  3 2016 tbechtold@suse.com
- Initial packaging (version 1.1.4)
